@@ -19,8 +19,7 @@ def to_proto_timestamp(dt: datetime) -> Timestamp:
 
 def to_proto_timestamp_range(s: datetime, e: datetime) -> TimestampRange:
     return TimestampRange(
-        start_dt=to_proto_timestamp(s),
-        end_dt=to_proto_timestamp(e)
+        start_dt=to_proto_timestamp(s), end_dt=to_proto_timestamp(e)
     )
 
 
@@ -39,18 +38,18 @@ def parse_value_by_type(s: str, t: int) -> typing.Any:
     elif t == 2:
         return int(s)
     elif t == 3:
-        return datetime.strptime(s, '%Y-%m-%d %H:%M:%S.%f')
+        return datetime.strptime(s, "%Y-%m-%d %H:%M:%S.%f")
     elif t == 4:
-        return s == 'true' or s == 'TRUE' or s == '1' or s == 1
+        return s == "true" or s == "TRUE" or s == "1" or s == 1
     elif t == 5:
         return float(s)
     elif t == 6:
         return s
     elif t == 7:
-        return datetime.strptime(s, '%Y-%m-%d')
+        return datetime.strptime(s, "%Y-%m-%d")
     elif t == 8:
-        return datetime.strptime(s, '%Y-%m-%d %H:%M:%S.%f')
+        return datetime.strptime(s, "%Y-%m-%d %H:%M:%S.%f")
     elif t == 9:
-        return datetime.strptime(s, '%H:%M:%S.%f')
+        return datetime.strptime(s, "%H:%M:%S.%f")
     elif t == 10:
         return json.loads(s)
